@@ -138,6 +138,11 @@ class FunctionArgPreProcessor:
         :param data_type: Expected data type of the param
         :return: type casted value
         """
+        if data_type in [dict, list]:
+            if isinstance(value, data_type):
+                return value
+            else:
+                raise Exception()
         if (isinstance(data_type, BaseArg) and isinstance(value, data_type.data_type) is False) or isinstance(value,
                                                                                                               data_type) is False:
             value = data_type(value)
